"""
Dictionaries module for NRCAN construction to Hub window CO2 emissions
SPDX - License - Identifier: LGPL - 3.0 - or -later
Copyright © 2019 - 2025 Concordia CERC group
Project Coder Koa Wells kekoa.wells@concordia.ca
"""

class NrcanConstructionToHubWindowCo2:
  """
  NRCAN construction to Hub window CO2 emissions class
  """

  """
  Note: since the embodied emissions and the end of life emissions for windows end up creating a different mapping,
        it was decided to keep the mapping from the embodied emissions, but to average the recycling_ratio (.1 and .15 
        replaced with 0.125) and assign it to all the end of life emissions. This means that all the end of life values
        for the windows are the same. 
  """

  def __init__(self):
    self._dictionary = {
      "Window_1000_1900_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_1000_1900_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_1000_1900_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1000_1900_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1000_1900_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1000_1900_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1901_1910_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_1901_1910_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_1901_1910_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1901_1910_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1901_1910_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1901_1910_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1911_1920_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_1911_1920_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_1911_1920_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1911_1920_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1911_1920_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1911_1920_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1921_1930_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_1921_1930_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_1921_1930_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1921_1930_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1921_1930_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1921_1930_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1931_1940_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_1931_1940_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_1931_1940_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1931_1940_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1931_1940_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1931_1940_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1941_1950_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_1941_1950_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_1941_1950_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1941_1950_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1941_1950_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1941_1950_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1951_1960_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_1951_1960_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_1951_1960_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1951_1960_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1951_1960_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1951_1960_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1961_1970_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_1961_1970_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_1961_1970_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1961_1970_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1961_1970_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1961_1970_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1971_1980_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_1971_1980_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_1971_1980_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1971_1980_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1971_1980_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1971_1980_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1981_1990_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_1981_1990_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_1981_1990_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1981_1990_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1981_1990_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1981_1990_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1991_2000_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_1991_2000_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_1991_2000_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1991_2000_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1991_2000_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_1991_2000_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_2001_2010_4": {
        "name": "window_1",
        "factor": 1.0
      },
      "Window_2001_2010_5": {
        "name": "window_2",
        "factor": 1.0
      },
      "Window_2001_2010_6": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_2001_2010_7A": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_2001_2010_7B": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_2001_2010_8": {
        "name": "window_3",
        "factor": 1.0
      },
      "Window_2011_2016_4": {
        "name": "window_4",
        "factor": 1.0
      },
      "Window_2011_2016_5": {
        "name": "window_4",
        "factor": 1.0
      },
      "Window_2011_2016_6": {
        "name": "window_4",
        "factor": 1.0
      },
      "Window_2011_2016_7A": {
        "name": "window_4",
        "factor": 1.0
      },
      "Window_2011_2016_7B": {
        "name": "window_4",
        "factor": 1.0
      },
      "Window_2011_2016_8": {
        "name": "window_5",
        "factor": 1.0
      },
      "Window_2017_2019_4": {
        "name": "window_4",
        "factor": 1.0
      },
      "Window_2017_2019_5": {
        "name": "window_6",
        "factor": 1.0
      },
      "Window_2017_2019_6": {
        "name": "window_6",
        "factor": 1.0
      },
      "Window_2017_2019_7A": {
        "name": "window_6",
        "factor": 1.0
      },
      "Window_2017_2019_7B": {
        "name": "window_6",
        "factor": 1.0
      },
      "Window_2017_2019_8": {
        "name": "window_5",
        "factor": 1.0
      },
      "Window_2020_3000_4": {
        "name": "window_6",
        "factor": 1.0
      },
      "Skylight_2020_3000_4": {
        "name": "window_4",
        "factor": 1.0
      },
      "Window_2020_3000_5": {
        "name": "window_6",
        "factor": 1.0
      },
      "Skylight_2020_3000_5": {
        "name": "window_4",
        "factor": 1.0
      },
      "Window_2020_3000_6": {
        "name": "window_6",
        "factor": 1.0
      },
      "Skylight_2020_3000_6": {
        "name": "window_4",
        "factor": 1.0
      },
      "Window_2020_3000_7A": {
        "name": "window_6",
        "factor": 1.0
      },
      "Skylight_2020_3000_7A": {
        "name": "window_4",
        "factor": 1.0
      },
      "Window_2020_3000_7B": {
        "name": "window_5",
        "factor": 1.0
      },
      "Skylight_2020_3000_7B": {
        "name": "window_4",
        "factor": 1.0
      },
      "Window_2020_3000_8": {
        "name": "window_5",
        "factor": 1.0
      },
      "Skylight_2020_3000_8": {
        "name": "window_4",
        "factor": 1.0
      }
    }

  @property
  def dictionary(self) -> dict:
    """
    Get the dictionary
    :return: {}
    """
    return self._dictionary
